==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfDocumentLinkAnnotationWidget.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfDocumentLinkAnnotationWidget(PdfStyledAnnotationWidget):
    """
    Represents the loaded document link annotation class.
    """

    @property
    def Destination(self) -> 'PdfDestination':
        """
        Gets or Sets the destination of the annotation.
        """
        GetDllLibPdf().PdfDocumentLinkAnnotationWidget_get_Destination.argtypes = [c_void_p]
        GetDllLibPdf().PdfDocumentLinkAnnotationWidget_get_Destination.restype = c_void_p
        intPtr = GetDllLibPdf().PdfDocumentLinkAnnotationWidget_get_Destination(self.Ptr)
        ret = None if intPtr == None else PdfDestination(intPtr)
        return ret

    @Destination.setter
    def Destination(self, value: 'PdfDestination'):
        """
        Sets the destination of the annotation.
        """
        GetDllLibPdf().PdfDocumentLinkAnnotationWidget_set_Destination.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentLinkAnnotationWidget_set_Destination(self.Ptr, value.Ptr)

    def ObjectID(self) -> int:
        """
        Represents the Form field identifier.
        """
        GetDllLibPdf().PdfDocumentLinkAnnotationWidget_ObjectID.argtypes = [c_void_p]
        GetDllLibPdf().PdfDocumentLinkAnnotationWidget_ObjectID.restype = c_int
        ret = GetDllLibPdf().PdfDocumentLinkAnnotationWidget_ObjectID(self.Ptr)
        return ret

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfDocumentLinkAnnotationWidget.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfDocumentLinkAnnotationWidget(PdfStyledAnnotationWidget):
    """
    Represents the loaded document link annotation class.
    """

    @property
    def Destination(self) -> 'PdfDestination':
        """
        Gets or Sets the destination of the annotation.
        """
        GetDllLibPdf().PdfDocumentLinkAnnotationWidget_get_Destination.argtypes = [c_void_p]
        GetDllLibPdf().PdfDocumentLinkAnnotationWidget_get_Destination.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfDocumentLinkAnnotationWidget_get_Destination,self.Ptr)
        ret = None if intPtr == None else PdfDestination(intPtr)
        return ret

    @Destination.setter
    def Destination(self, value: 'PdfDestination'):
        """
        Sets the destination of the annotation.
        """
        GetDllLibPdf().PdfDocumentLinkAnnotationWidget_set_Destination.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfDocumentLinkAnnotationWidget_set_Destination,self.Ptr, value.Ptr)

    def ObjectID(self) -> int:
        """
        Represents the Form field identifier.
        """
        GetDllLibPdf().PdfDocumentLinkAnnotationWidget_ObjectID.argtypes = [c_void_p]
        GetDllLibPdf().PdfDocumentLinkAnnotationWidget_ObjectID.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfDocumentLinkAnnotationWidget_ObjectID,self.Ptr)
        return ret
